==> gesundheit-0.0.4.tgz: package/lib/base-query.js <==
(function() {
  var Query, copy, dialects, fluid, passthrough_resolver;
  var __bind = function(fn, me){ return function(){ return fn.apply(me, arguments); }; };
  fluid = require('./fluid');
  dialects = require('./dialects');
  module.exports = Query = (function() {
    function Query(opts) {
      this.dialect = opts.dialect || dialects["default"];
      this.resolve = opts.resolver || passthrough_resolver;
      this.s = {};
    }
    Query.prototype.clone = function() {
      var child;
      child = new this.constructor;
      child.dialect = this.dialect;
      child.resolve = this.resolve;
      child.s = copy(this.s);
      return child;
    };
    Query.prototype.visit = fluid(function(fn) {
      if (fn != null) {
        return fn.call(this, this);
      }
    });
    Query.prototype.toSql = function() {
      return this.dialect["render" + this.s.queryType](this.s);
    };
    Query.prototype.execute = function(conn, cb) {
      if (conn['acquire'] != null) {
        return conn.acquire(__bind(function(c) {
          return this.execute(c, cb);
        }, this));
      } else {
        return conn.query(this.toSql(), this.s.parameters, cb);
      }
    };
    Query.prototype.toString = function() {
      return "[Query \"" + (this.toSql().substring(0, 20)) + "\"]";
    };
    return Query;
  })();
  passthrough_resolver = {
    table: function(n) {
      return n;
    },
    field: function(t, n) {
      return n;
    }
  };
  copy = function(thing) {
    var c, k, obj, v;
    if (thing === null) {
      return null;
    } else if (thing.constructor === Array) {
      c = [];
      c.push.apply(c, thing);
      return c;
    } else if ('object' === typeof thing) {
      obj = {};
      for (k in thing) {
        v = thing[k];
        obj[k] = copy(v);
      }
      return obj;
    } else {
      return thing;
    }
  };
}).call(this);

==> gesundheit-0.1.1.tgz: package/lib/base-query.js <==
(function() {
  var Query, copy, dialects, fluid, passthrough_resolver;
  var __bind = function(fn, me){ return function(){ return fn.apply(me, arguments); }; };
  fluid = require('./fluid');
  dialects = require('./dialects');
  module.exports = Query = (function() {
    function Query(opts) {
      var checks, condition, description, method, orig, _fn, _ref;
      this.dialect = opts.dialect || dialects["default"];
      this.resolve = opts.resolver || passthrough_resolver;
      if (this.dialect.pre != null) {
        _ref = this.dialect.pre;
        for (method in _ref) {
          checks = _ref[method];
          _fn = __bind(function(method, description, orig, condition) {
            return this[method] = function() {
              if (condition.apply(this.s, arguments)) {
                return orig.apply(this, arguments);
              } else {
                throw new Error(description);
              }
            };
          }, this);
          for (description in checks) {
            condition = checks[description];
            if (!(orig = this[method])) {
              continue;
            }
            _fn(method, description, orig, condition);
          }
        }
      }
      this.s = {};
    }
    Query.prototype.clone = function() {
      var child;
      child = new this.constructor;
      child.dialect = this.dialect;
      child.resolve = this.resolve;
      child.s = copy(this.s);
      return child;
    };
    Query.prototype.visit = fluid(function(fn) {
      if (fn != null) {
        return fn.call(this, this);
      }
    });
    Query.prototype.toSql = function() {
      return this.dialect["render" + this.s.queryType](this.s);
    };
    Query.prototype.execute = function(conn, cb) {
      if (conn['acquire'] != null) {
        return conn.acquire(__bind(function(c) {
          return this.execute(c, cb);
        }, this));
      } else {
        return conn.query(this.toSql(), this.s.parameters, cb);
      }
    };
    Query.prototype.toString = function() {
      return "[Query \"" + (this.toSql().substring(0, 20)) + "\"]";
    };
    return Query;
  })();
  passthrough_resolver = {
    table: function(t) {
      return t;
    },
    field: function(t, f) {
      return f;
    },
    value: function(t, f, v) {
      return v;
    }
  };
  copy = function(thing) {
    var c, k, obj, v;
    if (thing === null) {
      return null;
    } else if (thing.constructor === Array) {
      c = [];
      c.push.apply(c, thing);
      return c;
    } else if ('object' === typeof thing) {
      obj = {};
      for (k in thing) {
        v = thing[k];
        obj[k] = copy(v);
      }
      return obj;
    } else {
      return thing;
    }
  };
}).call(this);
